@@ -46,6 +46,10 @@ regularize_vpts <- function(ts, interval = "auto", date_min = ts$daterange[1],
   stopifnot(inherits(date_min, "POSIXct"))
   stopifnot(inherits(date_max, "POSIXct"))
 
+  # @param keep_datetime Logical, when \code{TRUE} keep original radar acquisition timestamps,
+  # and do not update to values of the regularized time grid.
+  keep_datetime <- FALSE # option under development
+
   if (!(units %in% c("secs", "mins", "hours", "days", "weeks"))) {
     stop(
       "Invalid 'units' argument. Should be one of",
@@ -85,6 +89,7 @@ regularize_vpts <- function(ts, interval = "auto", date_min = ts$daterange[1],
       ts$data[[x]][, index]
     }
   )
+  index2 <- integer(0)
   if (!fill) {
     index2 <- which(abs(ts$datetime[index] - grid) > as.double(dt, units = "secs"))
     if (length(index2) > 0) {
@@ -99,8 +104,14 @@ regularize_vpts <- function(ts, interval = "auto", date_min = ts$daterange[1],
     }
   }
   names(ts$data) <- quantity.names
-  ts$datetime <- grid
-  ts$timesteps <- rep(as.double(dt, units = "secs"), length(grid) - 1)
+  if(!keep_datetime){
+    ts$datetime <- grid
+    ts$timesteps <- rep(as.double(dt, units = "secs"), length(grid) - 1)
+  } else{
+    ts$datetime <- ts$datetime[index]
+    ts$timesteps <- difftime(ts$datetime[-1], ts$datetime[-length(ts$datetime)], units = "secs")
+    ts$timesteps[index2] <- dt
+  }
   ts$regular <- TRUE
   return(ts)
 }
